You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2015/02/16 23:40:22 UTC

[52/82] [math] Update for next development iteration: commons-math4

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/MathArraysTest.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/MathArraysTest.java b/src/test/java/org/apache/commons/math4/util/MathArraysTest.java
index e4918ce..71d75b9 100644
--- a/src/test/java/org/apache/commons/math4/util/MathArraysTest.java
+++ b/src/test/java/org/apache/commons/math4/util/MathArraysTest.java
@@ -11,21 +11,24 @@
  * KIND, either express or implied. See the License for the specific language
  * governing permissions and limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.Arrays;
 
-import org.apache.commons.math3.TestUtils;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NoDataException;
-import org.apache.commons.math3.exception.NonMonotonicSequenceException;
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.NotANumberException;
-import org.apache.commons.math3.random.Well1024a;
+import org.apache.commons.math4.TestUtils;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NoDataException;
+import org.apache.commons.math4.exception.NonMonotonicSequenceException;
+import org.apache.commons.math4.exception.NotANumberException;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.random.Well1024a;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathArrays;
+import org.apache.commons.math4.util.Precision;
 import org.junit.Assert;
 import org.junit.Test;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/MathUtilsTest.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/MathUtilsTest.java b/src/test/java/org/apache/commons/math4/util/MathUtilsTest.java
index 2089bf5..b9beee3 100644
--- a/src/test/java/org/apache/commons/math4/util/MathUtilsTest.java
+++ b/src/test/java/org/apache/commons/math4/util/MathUtilsTest.java
@@ -11,15 +11,17 @@
  * KIND, either express or implied. See the License for the specific language
  * governing permissions and limitations under the License.
  */
-package org.apache.commons.math3.util;
-
-import org.apache.commons.math3.distribution.RealDistribution;
-import org.apache.commons.math3.distribution.UniformRealDistribution;
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.NotFiniteNumberException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.random.RandomDataGenerator;
+package org.apache.commons.math4.util;
+
+import org.apache.commons.math4.distribution.RealDistribution;
+import org.apache.commons.math4.distribution.UniformRealDistribution;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.NotFiniteNumberException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.random.RandomDataGenerator;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathUtils;
 import org.junit.Assert;
 import org.junit.Test;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/MultidimensionalCounterTest.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/MultidimensionalCounterTest.java b/src/test/java/org/apache/commons/math4/util/MultidimensionalCounterTest.java
index 4f88d96..9966810 100644
--- a/src/test/java/org/apache/commons/math4/util/MultidimensionalCounterTest.java
+++ b/src/test/java/org/apache/commons/math4/util/MultidimensionalCounterTest.java
@@ -15,12 +15,14 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.NoSuchElementException;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.OutOfRangeException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.util.MultidimensionalCounter;
 import org.junit.Assert;
 import org.junit.Test;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/OpenIntToDoubleHashMapTest.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/OpenIntToDoubleHashMapTest.java b/src/test/java/org/apache/commons/math4/util/OpenIntToDoubleHashMapTest.java
index 2e3d72b..0841868 100644
--- a/src/test/java/org/apache/commons/math4/util/OpenIntToDoubleHashMapTest.java
+++ b/src/test/java/org/apache/commons/math4/util/OpenIntToDoubleHashMapTest.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.ConcurrentModificationException;
 import java.util.HashMap;
@@ -24,6 +24,8 @@ import java.util.NoSuchElementException;
 import java.util.Random;
 import java.util.Set;
 
+import org.apache.commons.math4.util.OpenIntToDoubleHashMap;
+import org.apache.commons.math4.util.Precision;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/OpenIntToFieldTest.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/OpenIntToFieldTest.java b/src/test/java/org/apache/commons/math4/util/OpenIntToFieldTest.java
index 3a5ea08..6df12dd 100644
--- a/src/test/java/org/apache/commons/math4/util/OpenIntToFieldTest.java
+++ b/src/test/java/org/apache/commons/math4/util/OpenIntToFieldTest.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.ConcurrentModificationException;
 import java.util.HashMap;
@@ -25,10 +25,11 @@ import java.util.Random;
 import java.util.Set;
 import java.util.Map.Entry;
 
-import org.apache.commons.math3.Field;
-import org.apache.commons.math3.fraction.Fraction;
-import org.apache.commons.math3.fraction.FractionConversionException;
-import org.apache.commons.math3.fraction.FractionField;
+import org.apache.commons.math4.Field;
+import org.apache.commons.math4.fraction.Fraction;
+import org.apache.commons.math4.fraction.FractionConversionException;
+import org.apache.commons.math4.fraction.FractionField;
+import org.apache.commons.math4.util.OpenIntToFieldHashMap;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/PairTest.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/PairTest.java b/src/test/java/org/apache/commons/math4/util/PairTest.java
index 73d1fdb..904c93c 100644
--- a/src/test/java/org/apache/commons/math4/util/PairTest.java
+++ b/src/test/java/org/apache/commons/math4/util/PairTest.java
@@ -11,8 +11,9 @@
  * KIND, either express or implied. See the License for the specific language
  * governing permissions and limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
+import org.apache.commons.math4.util.Pair;
 import org.junit.Assert;
 import org.junit.Test;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/PrecisionTest.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/PrecisionTest.java b/src/test/java/org/apache/commons/math4/util/PrecisionTest.java
index 12a520e..3d133d7 100644
--- a/src/test/java/org/apache/commons/math4/util/PrecisionTest.java
+++ b/src/test/java/org/apache/commons/math4/util/PrecisionTest.java
@@ -11,13 +11,15 @@
  * KIND, either express or implied. See the License for the specific language
  * governing permissions and limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.math.BigDecimal;
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.TestUtils;
 
+import org.apache.commons.math4.TestUtils;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.Precision;
 import org.junit.Assert;
 import org.junit.Test;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/ResizableDoubleArrayTest.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/ResizableDoubleArrayTest.java b/src/test/java/org/apache/commons/math4/util/ResizableDoubleArrayTest.java
index 6d9d244..c91de57 100644
--- a/src/test/java/org/apache/commons/math4/util/ResizableDoubleArrayTest.java
+++ b/src/test/java/org/apache/commons/math4/util/ResizableDoubleArrayTest.java
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
-
-import org.apache.commons.math3.distribution.IntegerDistribution;
-import org.apache.commons.math3.distribution.UniformIntegerDistribution;
+package org.apache.commons.math4.util;
 
+import org.apache.commons.math4.distribution.IntegerDistribution;
+import org.apache.commons.math4.distribution.UniformIntegerDistribution;
+import org.apache.commons.math4.util.MathArrays;
+import org.apache.commons.math4.util.ResizableDoubleArray;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/TestBean.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/TestBean.java b/src/test/java/org/apache/commons/math4/util/TestBean.java
index ee3b70e..627a20b 100644
--- a/src/test/java/org/apache/commons/math4/util/TestBean.java
+++ b/src/test/java/org/apache/commons/math4/util/TestBean.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
-import org.apache.commons.math3.exception.MathUnsupportedOperationException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathUnsupportedOperationException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  */

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/java/org/apache/commons/math4/util/TransformerMapTest.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/math4/util/TransformerMapTest.java b/src/test/java/org/apache/commons/math4/util/TransformerMapTest.java
index 11fe5ef..796ec69 100644
--- a/src/test/java/org/apache/commons/math4/util/TransformerMapTest.java
+++ b/src/test/java/org/apache/commons/math4/util/TransformerMapTest.java
@@ -15,9 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
-import org.apache.commons.math3.TestUtils;
+import org.apache.commons.math4.TestUtils;
+import org.apache.commons.math4.util.DefaultTransformer;
+import org.apache.commons.math4.util.NumberTransformer;
+import org.apache.commons.math4.util.TransformerMap;
 import org.junit.Assert;
 import org.junit.Test;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/maxima/special/RealFunctionValidation/README.txt
----------------------------------------------------------------------
diff --git a/src/test/maxima/special/RealFunctionValidation/README.txt b/src/test/maxima/special/RealFunctionValidation/README.txt
index a9a2d46..dc346e3 100644
--- a/src/test/maxima/special/RealFunctionValidation/README.txt
+++ b/src/test/maxima/special/RealFunctionValidation/README.txt
@@ -42,7 +42,7 @@ Compile the source file. The jar file of Commons-Math3 should be included in
 your classpath. If it is installed in your local maven repository, the
 following command should work
 
-  javac -classpath $HOME/.m2/repository/org/apache/commons/commons-math3/3.1-SNAPSHOT/commons-math3-3.1-SNAPSHOT.jar RealFunctionValidation.java
+  javac -classpath $HOME/.m2/repository/org/apache/commons/commons-math4/4.0-SNAPSHOT/commons-math4-4.0-SNAPSHOT.jar RealFunctionValidation.java
 
 Create a jar file
 
@@ -99,7 +99,7 @@ file
 As an example, here is the properties file for evaluation of
 double Gamma.logGamma(double)
 
-method=org.apache.commons.math3.special.Gamma.logGamma
+method=org.apache.commons.math4.special.Gamma.logGamma
 signature=double
 inputFileMask=logGamma-%02d.dat
 outputFileMask=logGamma-out-%02d.dat

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.java
----------------------------------------------------------------------
diff --git a/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.java b/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.java
index a9ef129..873e5c4 100755
--- a/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.java
+++ b/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.java
@@ -28,8 +28,8 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Properties;
 
-import org.apache.commons.math3.stat.descriptive.SummaryStatistics;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.stat.descriptive.SummaryStatistics;
+import org.apache.commons.math4.util.FastMath;
 
 /*
  * plot 'logGamma.dat' binary format="%double%double" endian=big u 1:2 w l

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.sh
----------------------------------------------------------------------
diff --git a/src/test/maxima/special/reference/gamma.properties b/src/test/maxima/special/reference/gamma.properties
index 296ee28..8a13d13 100755
--- a/src/test/maxima/special/reference/gamma.properties
+++ b/src/test/maxima/special/reference/gamma.properties
@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-method=org.apache.commons.math3.special.Gamma.gamma
+method=org.apache.commons.math4.special.Gamma.gamma
 signature=double
 inputFileMask=gamma-%02d.dat
 outputFileMask=gamma-out-%02d.dat

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/maxima/special/reference/logBeta.properties
----------------------------------------------------------------------
diff --git a/src/test/maxima/special/reference/logBeta.properties b/src/test/maxima/special/reference/logBeta.properties
index 7b79f60..ecc5751 100755
--- a/src/test/maxima/special/reference/logBeta.properties
+++ b/src/test/maxima/special/reference/logBeta.properties
@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-method=org.apache.commons.math3.special.Beta.logBeta
+method=org.apache.commons.math4.special.Beta.logBeta
 signature=double, double
 inputFileMask=logBeta-%02d.dat
 outputFileMask=logBeta-out-%02d.dat

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/maxima/special/reference/logGamma.properties
----------------------------------------------------------------------
diff --git a/src/test/maxima/special/reference/logGamma.properties b/src/test/maxima/special/reference/logGamma.properties
index aac96de..4608031 100755
--- a/src/test/maxima/special/reference/logGamma.properties
+++ b/src/test/maxima/special/reference/logGamma.properties
@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-method=org.apache.commons.math3.special.Gamma.logGamma
+method=org.apache.commons.math4.special.Gamma.logGamma
 signature=double
 inputFileMask=logGamma-%02d.dat
 outputFileMask=logGamma-out-%02d.dat

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/README
----------------------------------------------------------------------
diff --git a/src/userguide/README b/src/userguide/README
index 2bf7766..9aa0238 100644
--- a/src/userguide/README
+++ b/src/userguide/README
@@ -1,8 +1,8 @@
 This directory contains source code that is not part of the Apache
-Commons Math library.  It contains syntaxically correct and working
+Commons Math library.  It contains syntactically correct and working
 examples of use.
 
 In order to run one of the applications (a class that must contain a
 "main" method), you would type (in a shell console) a command similar
 to the following:
- $ mvn -q exec:java -Dexec.mainClass=org.apache.commons.math3.userguide.sofm.ChineseRingsClassifier
+ $ mvn -q exec:java -Dexec.mainClass=org.apache.commons.math4.userguide.sofm.ChineseRingsClassifier

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/ClusterAlgorithmComparison.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/ClusterAlgorithmComparison.java b/src/userguide/java/org/apache/commons/math4/userguide/ClusterAlgorithmComparison.java
index 946d39c..b85b2ef 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/ClusterAlgorithmComparison.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/ClusterAlgorithmComparison.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide;
+package org.apache.commons.math4.userguide;
 
 import java.awt.Color;
 import java.awt.Dimension;
@@ -34,23 +34,23 @@ import java.util.List;
 import javax.swing.JComponent;
 import javax.swing.JLabel;
 
-import org.apache.commons.math3.distribution.NormalDistribution;
-import org.apache.commons.math3.geometry.euclidean.twod.Vector2D;
-import org.apache.commons.math3.ml.clustering.CentroidCluster;
-import org.apache.commons.math3.ml.clustering.Cluster;
-import org.apache.commons.math3.ml.clustering.Clusterable;
-import org.apache.commons.math3.ml.clustering.Clusterer;
-import org.apache.commons.math3.ml.clustering.DBSCANClusterer;
-import org.apache.commons.math3.ml.clustering.DoublePoint;
-import org.apache.commons.math3.ml.clustering.FuzzyKMeansClusterer;
-import org.apache.commons.math3.ml.clustering.KMeansPlusPlusClusterer;
-import org.apache.commons.math3.random.RandomAdaptor;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.random.SobolSequenceGenerator;
-import org.apache.commons.math3.random.Well19937c;
-import org.apache.commons.math3.userguide.ExampleUtils.ExampleFrame;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.Pair;
+import org.apache.commons.math4.distribution.NormalDistribution;
+import org.apache.commons.math4.geometry.euclidean.twod.Vector2D;
+import org.apache.commons.math4.ml.clustering.CentroidCluster;
+import org.apache.commons.math4.ml.clustering.Cluster;
+import org.apache.commons.math4.ml.clustering.Clusterable;
+import org.apache.commons.math4.ml.clustering.Clusterer;
+import org.apache.commons.math4.ml.clustering.DBSCANClusterer;
+import org.apache.commons.math4.ml.clustering.DoublePoint;
+import org.apache.commons.math4.ml.clustering.FuzzyKMeansClusterer;
+import org.apache.commons.math4.ml.clustering.KMeansPlusPlusClusterer;
+import org.apache.commons.math4.random.RandomAdaptor;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.random.SobolSequenceGenerator;
+import org.apache.commons.math4.random.Well19937c;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.Pair;
+import org.apache.commons.math4.userguide.ExampleUtils.ExampleFrame;
 
 /**
  * Plots clustering results for various algorithms and datasets.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/ExampleUtils.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/ExampleUtils.java b/src/userguide/java/org/apache/commons/math4/userguide/ExampleUtils.java
index b173519..e58540d 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/ExampleUtils.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/ExampleUtils.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide;
+package org.apache.commons.math4.userguide;
 
 import java.awt.Component;
 import java.awt.event.ActionEvent;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/LowDiscrepancyGeneratorComparison.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/LowDiscrepancyGeneratorComparison.java b/src/userguide/java/org/apache/commons/math4/userguide/LowDiscrepancyGeneratorComparison.java
index 19426de..39b0b32 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/LowDiscrepancyGeneratorComparison.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/LowDiscrepancyGeneratorComparison.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide;
+package org.apache.commons.math4.userguide;
 
 import java.awt.Color;
 import java.awt.Dimension;
@@ -32,18 +32,18 @@ import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JTextArea;
 
-import org.apache.commons.math3.geometry.euclidean.twod.Vector2D;
-import org.apache.commons.math3.random.HaltonSequenceGenerator;
-import org.apache.commons.math3.random.JDKRandomGenerator;
-import org.apache.commons.math3.random.MersenneTwister;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.random.RandomVectorGenerator;
-import org.apache.commons.math3.random.SobolSequenceGenerator;
-import org.apache.commons.math3.random.UncorrelatedRandomVectorGenerator;
-import org.apache.commons.math3.random.UniformRandomGenerator;
-import org.apache.commons.math3.userguide.ExampleUtils.ExampleFrame;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.Pair;
+import org.apache.commons.math4.geometry.euclidean.twod.Vector2D;
+import org.apache.commons.math4.random.HaltonSequenceGenerator;
+import org.apache.commons.math4.random.JDKRandomGenerator;
+import org.apache.commons.math4.random.MersenneTwister;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.random.RandomVectorGenerator;
+import org.apache.commons.math4.random.SobolSequenceGenerator;
+import org.apache.commons.math4.random.UncorrelatedRandomVectorGenerator;
+import org.apache.commons.math4.random.UniformRandomGenerator;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.Pair;
+import org.apache.commons.math4.userguide.ExampleUtils.ExampleFrame;
 
 /**
  * Plots 2D samples drawn from various pseudo / quasi-random generators.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/RealDistributionComparison.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/RealDistributionComparison.java b/src/userguide/java/org/apache/commons/math4/userguide/RealDistributionComparison.java
index b8971cd..6c7ec71 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/RealDistributionComparison.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/RealDistributionComparison.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide;
+package org.apache.commons.math4.userguide;
 
 import java.awt.BasicStroke;
 import java.awt.Color;
@@ -33,23 +33,23 @@ import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JScrollPane;
 
-import org.apache.commons.math3.distribution.BetaDistribution;
-import org.apache.commons.math3.distribution.CauchyDistribution;
-import org.apache.commons.math3.distribution.ChiSquaredDistribution;
-import org.apache.commons.math3.distribution.ExponentialDistribution;
-import org.apache.commons.math3.distribution.FDistribution;
-import org.apache.commons.math3.distribution.GammaDistribution;
-import org.apache.commons.math3.distribution.LevyDistribution;
-import org.apache.commons.math3.distribution.LogNormalDistribution;
-import org.apache.commons.math3.distribution.NormalDistribution;
-import org.apache.commons.math3.distribution.ParetoDistribution;
-import org.apache.commons.math3.distribution.RealDistribution;
-import org.apache.commons.math3.distribution.TDistribution;
-import org.apache.commons.math3.distribution.WeibullDistribution;
-import org.apache.commons.math3.random.MersenneTwister;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.userguide.ExampleUtils.ExampleFrame;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.distribution.BetaDistribution;
+import org.apache.commons.math4.distribution.CauchyDistribution;
+import org.apache.commons.math4.distribution.ChiSquaredDistribution;
+import org.apache.commons.math4.distribution.ExponentialDistribution;
+import org.apache.commons.math4.distribution.FDistribution;
+import org.apache.commons.math4.distribution.GammaDistribution;
+import org.apache.commons.math4.distribution.LevyDistribution;
+import org.apache.commons.math4.distribution.LogNormalDistribution;
+import org.apache.commons.math4.distribution.NormalDistribution;
+import org.apache.commons.math4.distribution.ParetoDistribution;
+import org.apache.commons.math4.distribution.RealDistribution;
+import org.apache.commons.math4.distribution.TDistribution;
+import org.apache.commons.math4.distribution.WeibullDistribution;
+import org.apache.commons.math4.random.MersenneTwister;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.userguide.ExampleUtils.ExampleFrame;
 
 import com.xeiam.xchart.Chart;
 import com.xeiam.xchart.ChartBuilder;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/filter/CannonballExample.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/filter/CannonballExample.java b/src/userguide/java/org/apache/commons/math4/userguide/filter/CannonballExample.java
index c4414ee..7211a6b 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/filter/CannonballExample.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/filter/CannonballExample.java
@@ -12,7 +12,7 @@
  * governing permissions and limitations under the License.
  */
 
-package org.apache.commons.math3.userguide.filter;
+package org.apache.commons.math4.userguide.filter;
 
 import java.awt.Color;
 import java.awt.Component;
@@ -25,19 +25,19 @@ import javax.swing.BoxLayout;
 import javax.swing.JComponent;
 import javax.swing.JPanel;
 
-import org.apache.commons.math3.filter.DefaultMeasurementModel;
-import org.apache.commons.math3.filter.DefaultProcessModel;
-import org.apache.commons.math3.filter.KalmanFilter;
-import org.apache.commons.math3.filter.MeasurementModel;
-import org.apache.commons.math3.filter.ProcessModel;
-import org.apache.commons.math3.linear.MatrixUtils;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.linear.RealVector;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.random.Well19937c;
-import org.apache.commons.math3.userguide.ExampleUtils;
-import org.apache.commons.math3.userguide.ExampleUtils.ExampleFrame;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.filter.DefaultMeasurementModel;
+import org.apache.commons.math4.filter.DefaultProcessModel;
+import org.apache.commons.math4.filter.KalmanFilter;
+import org.apache.commons.math4.filter.MeasurementModel;
+import org.apache.commons.math4.filter.ProcessModel;
+import org.apache.commons.math4.linear.MatrixUtils;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.linear.RealVector;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.random.Well19937c;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.userguide.ExampleUtils;
+import org.apache.commons.math4.userguide.ExampleUtils.ExampleFrame;
 
 import com.xeiam.xchart.Chart;
 import com.xeiam.xchart.ChartBuilder;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/filter/ConstantVoltageExample.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/filter/ConstantVoltageExample.java b/src/userguide/java/org/apache/commons/math4/userguide/filter/ConstantVoltageExample.java
index d6d9f51..bf554d5 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/filter/ConstantVoltageExample.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/filter/ConstantVoltageExample.java
@@ -12,7 +12,7 @@
  * governing permissions and limitations under the License.
  */
 
-package org.apache.commons.math3.userguide.filter;
+package org.apache.commons.math4.userguide.filter;
 
 import java.awt.Color;
 import java.awt.Component;
@@ -25,19 +25,19 @@ import javax.swing.BoxLayout;
 import javax.swing.JComponent;
 import javax.swing.JPanel;
 
-import org.apache.commons.math3.filter.DefaultMeasurementModel;
-import org.apache.commons.math3.filter.DefaultProcessModel;
-import org.apache.commons.math3.filter.KalmanFilter;
-import org.apache.commons.math3.filter.MeasurementModel;
-import org.apache.commons.math3.filter.ProcessModel;
-import org.apache.commons.math3.linear.Array2DRowRealMatrix;
-import org.apache.commons.math3.linear.ArrayRealVector;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.linear.RealVector;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.random.Well19937c;
-import org.apache.commons.math3.userguide.ExampleUtils;
-import org.apache.commons.math3.userguide.ExampleUtils.ExampleFrame;
+import org.apache.commons.math4.filter.DefaultMeasurementModel;
+import org.apache.commons.math4.filter.DefaultProcessModel;
+import org.apache.commons.math4.filter.KalmanFilter;
+import org.apache.commons.math4.filter.MeasurementModel;
+import org.apache.commons.math4.filter.ProcessModel;
+import org.apache.commons.math4.linear.Array2DRowRealMatrix;
+import org.apache.commons.math4.linear.ArrayRealVector;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.linear.RealVector;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.random.Well19937c;
+import org.apache.commons.math4.userguide.ExampleUtils;
+import org.apache.commons.math4.userguide.ExampleUtils.ExampleFrame;
 
 import com.xeiam.xchart.Chart;
 import com.xeiam.xchart.ChartBuilder;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/genetics/HelloWorldExample.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/genetics/HelloWorldExample.java b/src/userguide/java/org/apache/commons/math4/userguide/genetics/HelloWorldExample.java
index b4db00f..a02cc8e 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/genetics/HelloWorldExample.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/genetics/HelloWorldExample.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide.genetics;
+package org.apache.commons.math4.userguide.genetics;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -23,19 +23,19 @@ import java.util.List;
 
 import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.lang3.RandomStringUtils;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.genetics.AbstractListChromosome;
-import org.apache.commons.math3.genetics.Chromosome;
-import org.apache.commons.math3.genetics.ElitisticListPopulation;
-import org.apache.commons.math3.genetics.GeneticAlgorithm;
-import org.apache.commons.math3.genetics.InvalidRepresentationException;
-import org.apache.commons.math3.genetics.MutationPolicy;
-import org.apache.commons.math3.genetics.OnePointCrossover;
-import org.apache.commons.math3.genetics.Population;
-import org.apache.commons.math3.genetics.StoppingCondition;
-import org.apache.commons.math3.genetics.TournamentSelection;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.genetics.AbstractListChromosome;
+import org.apache.commons.math4.genetics.Chromosome;
+import org.apache.commons.math4.genetics.ElitisticListPopulation;
+import org.apache.commons.math4.genetics.GeneticAlgorithm;
+import org.apache.commons.math4.genetics.InvalidRepresentationException;
+import org.apache.commons.math4.genetics.MutationPolicy;
+import org.apache.commons.math4.genetics.OnePointCrossover;
+import org.apache.commons.math4.genetics.Population;
+import org.apache.commons.math4.genetics.StoppingCondition;
+import org.apache.commons.math4.genetics.TournamentSelection;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.Precision;
 
 public class HelloWorldExample {
     public static final int    POPULATION_SIZE   = 1000;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/genetics/ImageEvolutionExample.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/genetics/ImageEvolutionExample.java b/src/userguide/java/org/apache/commons/math4/userguide/genetics/ImageEvolutionExample.java
index 6912384..ee038a3 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/genetics/ImageEvolutionExample.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/genetics/ImageEvolutionExample.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide.genetics;
+package org.apache.commons.math4.userguide.genetics;
 
 import java.awt.Component;
 import java.awt.Dimension;
@@ -35,14 +35,14 @@ import javax.swing.ImageIcon;
 import javax.swing.JButton;
 import javax.swing.JLabel;
 
-import org.apache.commons.math3.genetics.Chromosome;
-import org.apache.commons.math3.genetics.ElitisticListPopulation;
-import org.apache.commons.math3.genetics.GeneticAlgorithm;
-import org.apache.commons.math3.genetics.Population;
-import org.apache.commons.math3.genetics.TournamentSelection;
-import org.apache.commons.math3.genetics.UniformCrossover;
-import org.apache.commons.math3.userguide.ExampleUtils;
-import org.apache.commons.math3.userguide.ExampleUtils.ExampleFrame;
+import org.apache.commons.math4.genetics.Chromosome;
+import org.apache.commons.math4.genetics.ElitisticListPopulation;
+import org.apache.commons.math4.genetics.GeneticAlgorithm;
+import org.apache.commons.math4.genetics.Population;
+import org.apache.commons.math4.genetics.TournamentSelection;
+import org.apache.commons.math4.genetics.UniformCrossover;
+import org.apache.commons.math4.userguide.ExampleUtils;
+import org.apache.commons.math4.userguide.ExampleUtils.ExampleFrame;
 
 /**
  * This example shows a more advanced use of a genetic algorithm: approximate a raster image

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/genetics/Polygon.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/genetics/Polygon.java b/src/userguide/java/org/apache/commons/math4/userguide/genetics/Polygon.java
index 1950803..b6ad577 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/genetics/Polygon.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/genetics/Polygon.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide.genetics;
+package org.apache.commons.math4.userguide.genetics;
 
 import java.awt.Color;
 import java.awt.Graphics2D;
 import java.awt.geom.GeneralPath;
 
-import org.apache.commons.math3.genetics.GeneticAlgorithm;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.genetics.GeneticAlgorithm;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Represents a fixed size polgon with its fill color.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/genetics/PolygonChromosome.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/genetics/PolygonChromosome.java b/src/userguide/java/org/apache/commons/math4/userguide/genetics/PolygonChromosome.java
index 783b39f..d453541 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/genetics/PolygonChromosome.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/genetics/PolygonChromosome.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide.genetics;
+package org.apache.commons.math4.userguide.genetics;
 
 import java.awt.AlphaComposite;
 import java.awt.Color;
@@ -24,9 +24,9 @@ import java.awt.image.BufferedImage;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math3.genetics.AbstractListChromosome;
-import org.apache.commons.math3.genetics.Chromosome;
-import org.apache.commons.math3.genetics.InvalidRepresentationException;
+import org.apache.commons.math4.genetics.AbstractListChromosome;
+import org.apache.commons.math4.genetics.Chromosome;
+import org.apache.commons.math4.genetics.InvalidRepresentationException;
 
 /**
  * A simple chromosome representing a list of polygons.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/genetics/RandomPolygonMutation.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/genetics/RandomPolygonMutation.java b/src/userguide/java/org/apache/commons/math4/userguide/genetics/RandomPolygonMutation.java
index 57b4d10..9b6835a 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/genetics/RandomPolygonMutation.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/genetics/RandomPolygonMutation.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide.genetics;
+package org.apache.commons.math4.userguide.genetics;
 
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math3.genetics.Chromosome;
-import org.apache.commons.math3.genetics.MutationPolicy;
+import org.apache.commons.math4.genetics.Chromosome;
+import org.apache.commons.math4.genetics.MutationPolicy;
 
 public class RandomPolygonMutation implements MutationPolicy {
     

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/geometry/GeometryExample.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/geometry/GeometryExample.java b/src/userguide/java/org/apache/commons/math4/userguide/geometry/GeometryExample.java
index ea3ea3f..941243b 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/geometry/GeometryExample.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/geometry/GeometryExample.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.userguide.geometry;
+package org.apache.commons.math4.userguide.geometry;
 
 import java.awt.BorderLayout;
 import java.awt.Color;
@@ -31,21 +31,21 @@ import javax.swing.JComponent;
 import javax.swing.JPanel;
 import javax.swing.JSplitPane;
 
-import org.apache.commons.math3.geometry.enclosing.Encloser;
-import org.apache.commons.math3.geometry.enclosing.EnclosingBall;
-import org.apache.commons.math3.geometry.enclosing.WelzlEncloser;
-import org.apache.commons.math3.geometry.euclidean.twod.DiskGenerator;
-import org.apache.commons.math3.geometry.euclidean.twod.Euclidean2D;
-import org.apache.commons.math3.geometry.euclidean.twod.Segment;
-import org.apache.commons.math3.geometry.euclidean.twod.Vector2D;
-import org.apache.commons.math3.geometry.euclidean.twod.hull.ConvexHull2D;
-import org.apache.commons.math3.geometry.euclidean.twod.hull.ConvexHullGenerator2D;
-import org.apache.commons.math3.geometry.euclidean.twod.hull.MonotoneChain;
-import org.apache.commons.math3.random.MersenneTwister;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.userguide.ExampleUtils;
-import org.apache.commons.math3.userguide.ExampleUtils.ExampleFrame;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.geometry.enclosing.Encloser;
+import org.apache.commons.math4.geometry.enclosing.EnclosingBall;
+import org.apache.commons.math4.geometry.enclosing.WelzlEncloser;
+import org.apache.commons.math4.geometry.euclidean.twod.DiskGenerator;
+import org.apache.commons.math4.geometry.euclidean.twod.Euclidean2D;
+import org.apache.commons.math4.geometry.euclidean.twod.Segment;
+import org.apache.commons.math4.geometry.euclidean.twod.Vector2D;
+import org.apache.commons.math4.geometry.euclidean.twod.hull.ConvexHull2D;
+import org.apache.commons.math4.geometry.euclidean.twod.hull.ConvexHullGenerator2D;
+import org.apache.commons.math4.geometry.euclidean.twod.hull.MonotoneChain;
+import org.apache.commons.math4.random.MersenneTwister;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.userguide.ExampleUtils;
+import org.apache.commons.math4.userguide.ExampleUtils.ExampleFrame;
 import org.piccolo2d.PCamera;
 import org.piccolo2d.PCanvas;
 import org.piccolo2d.PNode;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRings.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRings.java b/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRings.java
index 1a7ad86..77cc75a 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRings.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRings.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.userguide.sofm;
+package org.apache.commons.math4.userguide.sofm;
 
-import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
-import org.apache.commons.math3.geometry.euclidean.threed.Rotation;
-import org.apache.commons.math3.random.UnitSphereRandomVectorGenerator;
-import org.apache.commons.math3.distribution.RealDistribution;
-import org.apache.commons.math3.distribution.UniformRealDistribution;
+import org.apache.commons.math4.geometry.euclidean.threed.Vector3D;
+import org.apache.commons.math4.geometry.euclidean.threed.Rotation;
+import org.apache.commons.math4.random.UnitSphereRandomVectorGenerator;
+import org.apache.commons.math4.distribution.RealDistribution;
+import org.apache.commons.math4.distribution.UniformRealDistribution;
 
 /**
  * Class that creates two intertwined rings.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRingsClassifier.java
----------------------------------------------------------------------
diff --git a/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRingsClassifier.java b/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRingsClassifier.java
index 871d9d6..6dbd36c 100644
--- a/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRingsClassifier.java
+++ b/src/userguide/java/org/apache/commons/math4/userguide/sofm/ChineseRingsClassifier.java
@@ -15,30 +15,30 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.userguide.sofm;
+package org.apache.commons.math4.userguide.sofm;
 
 import java.util.Iterator;
 import java.io.PrintWriter;
 import java.io.IOException;
-import org.apache.commons.math3.ml.neuralnet.SquareNeighbourhood;
-import org.apache.commons.math3.ml.neuralnet.FeatureInitializer;
-import org.apache.commons.math3.ml.neuralnet.FeatureInitializerFactory;
-import org.apache.commons.math3.ml.neuralnet.MapUtils;
-import org.apache.commons.math3.ml.neuralnet.twod.NeuronSquareMesh2D;
-import org.apache.commons.math3.ml.neuralnet.sofm.LearningFactorFunction;
-import org.apache.commons.math3.ml.neuralnet.sofm.LearningFactorFunctionFactory;
-import org.apache.commons.math3.ml.neuralnet.sofm.NeighbourhoodSizeFunction;
-import org.apache.commons.math3.ml.neuralnet.sofm.NeighbourhoodSizeFunctionFactory;
-import org.apache.commons.math3.ml.neuralnet.sofm.KohonenUpdateAction;
-import org.apache.commons.math3.ml.neuralnet.sofm.KohonenTrainingTask;
-import org.apache.commons.math3.ml.distance.DistanceMeasure;
-import org.apache.commons.math3.ml.distance.EuclideanDistance;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.random.Well19937c;
-import org.apache.commons.math3.stat.descriptive.SummaryStatistics;
-import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.exception.MathUnsupportedOperationException;
+import org.apache.commons.math4.ml.neuralnet.SquareNeighbourhood;
+import org.apache.commons.math4.ml.neuralnet.FeatureInitializer;
+import org.apache.commons.math4.ml.neuralnet.FeatureInitializerFactory;
+import org.apache.commons.math4.ml.neuralnet.MapUtils;
+import org.apache.commons.math4.ml.neuralnet.twod.NeuronSquareMesh2D;
+import org.apache.commons.math4.ml.neuralnet.sofm.LearningFactorFunction;
+import org.apache.commons.math4.ml.neuralnet.sofm.LearningFactorFunctionFactory;
+import org.apache.commons.math4.ml.neuralnet.sofm.NeighbourhoodSizeFunction;
+import org.apache.commons.math4.ml.neuralnet.sofm.NeighbourhoodSizeFunctionFactory;
+import org.apache.commons.math4.ml.neuralnet.sofm.KohonenUpdateAction;
+import org.apache.commons.math4.ml.neuralnet.sofm.KohonenTrainingTask;
+import org.apache.commons.math4.ml.distance.DistanceMeasure;
+import org.apache.commons.math4.ml.distance.EuclideanDistance;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.random.Well19937c;
+import org.apache.commons.math4.stat.descriptive.SummaryStatistics;
+import org.apache.commons.math4.geometry.euclidean.threed.Vector3D;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.exception.MathUnsupportedOperationException;
 
 /**
  * SOFM for categorizing points that belong to each of two intertwined rings.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/userguide/pom.xml
----------------------------------------------------------------------
diff --git a/src/userguide/pom.xml b/src/userguide/pom.xml
index 1daa91f..629d17f 100644
--- a/src/userguide/pom.xml
+++ b/src/userguide/pom.xml
@@ -21,8 +21,8 @@
 <project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
   <modelVersion>4.0.0</modelVersion>
   <groupId>org.apache.commons</groupId>
-  <artifactId>commons-math3-examples</artifactId>
-  <version>3.5-SNAPSHOT</version>  
+  <artifactId>commons-math4-examples</artifactId>
+  <version>4.0-SNAPSHOT</version>  
   <name>Commons Math User Guide</name>
   <inceptionYear>2003</inceptionYear>
   <description>Examples</description>
@@ -45,24 +45,6 @@
 
   <build>
     <sourceDirectory>java</sourceDirectory>
-    
-    <plugins>
-      <plugin>
-        <groupId>org.apache.maven.plugins</groupId>
-        <artifactId>maven-shade-plugin</artifactId>
-        <executions>
-          <execution>
-            <phase>package</phase>
-            <goals>
-              <goal>shade</goal>
-            </goals>
-          </execution>
-        </executions>
-        <configuration>
-          <finalName>${artifactId}-uber-${version}</finalName>
-        </configuration>
-      </plugin>
-    </plugins>
   </build>
   <reporting>
   </reporting>
@@ -70,8 +52,8 @@
   <dependencies>
       <dependency>
           <groupId>org.apache.commons</groupId>
-          <artifactId>commons-math3</artifactId>
-          <version>3.5-SNAPSHOT</version>
+          <artifactId>commons-math4</artifactId>
+          <version>4.0-SNAPSHOT</version>
       </dependency>
       <dependency>
           <groupId>com.xeiam.xchart</groupId>
diff --git a/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.sh b/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.sh
index 2cf3037..ec49121 100755
--- a/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.sh
+++ b/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.sh
@@ -15,10 +15,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Location of the Commons-Math3 jar file
-CM3_JAR=$HOME/.m2/repository/org/apache/commons/commons-math3/3.1-SNAPSHOT/commons-math3-3.1-SNAPSHOT.jar
+# Location of the Commons-Math4 jar file
+CM4_JAR=$HOME/.m2/repository/org/apache/commons/commons-math4/4.0-SNAPSHOT/commons-math4-4.0-SNAPSHOT.jar
 
 # Location of file RealFunctionValidation.jar
-APP_JAR=$HOME/Documents/workspace/commons-math3/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.jar
+APP_JAR=$HOME/Documents/workspace/commons-math4/src/test/maxima/special/RealFunctionValidation/RealFunctionValidation.jar
 
-java -cp $CM3_JAR:$APP_JAR RealFunctionValidation $1
\ No newline at end of file
+java -cp $CM4_JAR:$APP_JAR RealFunctionValidation $1
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/test/maxima/special/reference/gamma.properties
----------------------------------------------------------------------